@@ -17,6 +17,12 @@ class BadResultCodeError(TotalConnectError):
     pass
 
 
+class FeatureNotSupportedError(TotalConnectError):
+    """The user hardware and/or account permissions do not support
+    the requested feature.
+    """
+
+
 class RetryableTotalConnectError(TotalConnectError):
     """These errors are likely to resolve themselves if the action is retried.
     If an error requires some other action (such as reauthenticating an
